# :rocket: 数据分析实战 :facepunch:
---
## 数据运营实战
- [细分目标人群，结合用户画像的实践][1]
- [细分漏斗画像，改善关键节点][2]
- [用数据说话，从埋点开始][3]



















---
[1]: https://mp.weixin.qq.com/s/keezVbUJW3P1awDGLJ72AQ
[2]: https://mp.weixin.qq.com/s/5eP0F8MXsnu0Zft2sfEUGQ
[3]: https://mp.weixin.qq.com/s/eMdxRewVoe_7FMHltD-7bA
